Name:           drbd
Summary:        DRBD user-land tools and scripts
Version:        9.27.0
Release:        4
Source0:        http://www.linbit.com/downloads/%{name}/utils/%{name}-utils-%{version}.tar.gz
Patch0:         drbd-utils-9.12.2-disable_xsltproc_network_read.patch
Patch1:         drbd-utils-9.15.0-make_configure-workaround.patch
Patch2:         postparse-improve-file-line-error-message-reporting.patch
# https://github.com/LINBIT/drbd-utils/commit/60003dc13d0ce1533a831ec2d4cd3e4c7697ffa0
Patch3:         Update-scripts-drbd-to-fix-no-such-file-bug.patch
# https://github.com/LINBIT/drbd-utils/commit/0a825f1c859000b2143907b43a191e6dedb633f8
Patch4:         events2-set-may_promote-no-promotion_score-0.patch
# https://github.com/LINBIT/drbd-utils/commit/49a094b0bd71f76ca4917a852b64719a4ece91fb

License:        GPL-2.0-or-later
ExclusiveOS:    linux
URL:            http://www.drbd.org/
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  flex
BuildRequires:  libxslt
BuildRequires:  docbook-style-xsl
BuildRequires:  perl-generators
BuildRequires:  po4a
BuildRequires:  rubygem-asciidoctor
BuildRequires:  keyutils-libs-devel
Requires:       %{name}-utils = %{version}
Requires:       %{name}-udev = %{version}
BuildRequires:  udev
BuildRequires:  make

%description
DRBD refers to block devices designed as a building block to form high
availability (HA) clusters. This is done by mirroring a whole block device
via an assigned network. DRBD can be understood as network based raid-1.

This is a virtual package, installing the full user-land suite.

%files
%doc COPYING
%doc ChangeLog


%prep
%setup -q -n drbd-utils-%{version}

# Don't let xsltproc make network calls during build
%patch 0 -p1
%patch 1 -p1
%patch 2 -p1
%patch 3 -p1
%patch 4 -p1

%build
%configure \
    --with-utils \
    --without-km \
    --with-udev \
%ifarch %{ix86} x86_64
    --with-xen \
%else
    --without-xen \
%endif
    --with-pacemaker \
    --with-rgmanager \
    --with-distro=generic \
    --with-systemdunitdir=%{_unitdir}
%{make_build}

%install
rm -rf $RPM_BUILD_ROOT
%{make_install}

# Remove old init script, replace with systemd unit file
rm -f $RPM_BUILD_ROOT/%{_initddir}/drbd
install -d -m755 $RPM_BUILD_ROOT/%{_unitdir}

# Remove old heartbeat files that aren't needed any longer in Fedora
rm -rf $RPM_BUILD_ROOT/etc/ha.d

%package utils
Summary: Management utilities for DRBD

%description utils
DRBD mirrors a block device over the network to another machine.
Think of it as networked raid 1. It is a building block for
setting up high availability (HA) clusters.

This packages includes the DRBD administration tools.

%files utils
%defattr(755,root,root,-)
%{_sbindir}/drbdsetup
%{_sbindir}/drbdadm
%{_sbindir}/drbdmeta
%{_sbindir}/drbdmon

# systemd-related stuff
%attr(0644,root,root) %{_unitdir}/drbd.service
%attr(0644,root,root) %{_unitdir}/drbd-graceful-shutdown.service
%attr(0644,root,root) %{_unitdir}/drbd-demote-or-escalate@.service
%attr(0644,root,root) %{_unitdir}/drbd-lvchange@.service
%attr(0644,root,root) %{_unitdir}/drbd-promote@.service
%attr(0644,root,root) %{_unitdir}/drbd-reconfigure-suspend-or-error@.service
%attr(0644,root,root) %{_unitdir}/drbd-services@.target
%attr(0644,root,root) %{_unitdir}/drbd-wait-promotable@.service
%attr(0644,root,root) %{_unitdir}/drbd@.service
%attr(0644,root,root) %{_unitdir}/drbd@.target
%attr(0644,root,root) %{_unitdir}/ocf.ra@.service
%attr(0644,root,root) %{_tmpfilesdir}/%{name}.conf

# Yes, these paths are peculiar. Upstream is peculiar.
# Be forewarned: rpmlint hates this stuff.
%defattr(755,root,root,-)
/lib/drbd/scripts/drbd
/lib/drbd/scripts/drbd-service-shim.sh
/lib/drbd/scripts/drbd-wait-promotable.sh
/lib/drbd/scripts/ocf.ra.wrapper.sh
/lib/drbd/drbdadm-*
/lib/drbd/drbdsetup-*
/usr/lib/drbd/*.sh
/usr/lib/drbd/rhcs_fence

%defattr(-,root,root,-)
%dir %{_var}/lib/%{name}
%config(noreplace) %{_sysconfdir}/drbd.conf
%dir %{_sysconfdir}/drbd.d
%config(noreplace) %{_sysconfdir}/drbd.d/global_common.conf
%config(noreplace) %{_sysconfdir}/multipath/conf.d/drbd.conf
%{_mandir}/man8/drbd*gz
%{_mandir}/man5/drbd*gz
%{_mandir}/ja/man5/drbd*gz
%{_mandir}/ja/man8/drbd*gz
%{_mandir}/man7/drbd*@.service.*
%{_mandir}/man7/drbd*@.target.*
%{_mandir}/man7/drbd.service.*
%{_mandir}/man7/ocf.ra@.service.*
%doc scripts/drbd.conf.example
%license COPYING
%doc ChangeLog


# armv7hl/aarch64 doesn't have Xen packages
%ifarch %{ix86} x86_64
%package xen
Summary: Xen block device management script for DRBD
Requires: %{name}-utils = %{version}-%{release}

%description xen
This package contains a Xen block device helper script for DRBD, capable of
promoting and demoting DRBD resources as necessary.

%files xen
%defattr(755,root,root,-)
%{_sysconfdir}/xen/scripts/block-drbd
%endif


%package udev
Summary: udev integration scripts for DRBD
Requires: %{name}-utils = %{version}-%{release}, udev

%description udev
This package contains udev helper scripts for DRBD, managing symlinks to
DRBD devices in /dev/drbd/by-res and /dev/drbd/by-disk.

%files udev
%{_udevrulesdir}/65-drbd.rules


%package pacemaker
Summary: Pacemaker resource agent for DRBD
Requires: %{name}-utils = %{version}-%{release}
Requires: pacemaker
License: GPL-2.0-only

%description pacemaker
This package contains the master/slave DRBD resource agent for the
Pacemaker High Availability cluster manager.

%files pacemaker
%defattr(755,root,root,-)
%dir %{_prefix}/lib/ocf/resource.d/linbit/
%{_prefix}/lib/ocf/resource.d/linbit/drbd
%{_prefix}/lib/ocf/resource.d/linbit/drbd-attr
%{_prefix}/lib/ocf/resource.d/linbit/drbd.shellfuncs.sh
%{_mandir}/man7/ocf_linbit_drbd*gz


%package rgmanager
Summary: Red Hat Cluster Suite agent for DRBD
Requires: %{name}-utils = %{version}-%{release}

%description rgmanager
This package contains the DRBD resource agent for the Red Hat Cluster Suite
resource manager.

As of Red Hat Cluster Suite 3.0.1, the DRBD resource agent is included
in the Cluster distribution.

%files rgmanager
%defattr(755,root,root,-)
%{_datadir}/cluster/drbd.sh

%defattr(-,root,root,-)
%{_datadir}/cluster/drbd.metadata


%package bash-completion
Summary: Programmable bash completion support for drbdadm
Requires: %{name}-utils = %{version}-%{release}

%description bash-completion
This package contains programmable bash completion support for the drbdadm
management utility.

%files bash-completion
%config %{_sysconfdir}/bash_completion.d/drbdadm*


%post utils
%systemd_post drbd.service

%preun utils
%systemd_preun drbd.service

%changelog
* Thu Mar 21 2024 liupei <liupei@kylinos.cn> - 9.27.0-4
- events2: set may_promote:no promotion_score:0 while force-io-failure:yes 

* Tue Mar 19 2024 liupei <liupei@kylinos.cn> - 9.27.0-3
- Update scripts/drbd to fix "no such file" bug

* Mon Mar 18 2024 liupei <liupei@kylinos.cn> - 9.27.0-2
- postparse: improve "file:line: error message" reporting 

* Fri Mar 15 2024 liupei <liupei@kylinos.cn> - 9.27.0-1
- update to 9.27.0

* Mon Mar 11 2024 liupei <liupei@kylinos.cn> - 9.26.0-1
- update to 9.26.0
- Build requires keyutils-libs-devel

* Fri Mar 8 2024 liupei <liupei@kylinos.cn> - 9.25.0-1
- update to 9.25.0

* Tue Mar 5 2024 liupei <liupei@kylinos.cn> - 9.24.0-1
- update to 9.24.0

* Thu Feb 29 2024 liupei <liupei@kylinos.cn> - 9.23.1-1
- update to 9.23.1

* Wed Feb 28 2024 liupei <liupei@kylinos.cn> - 9.23.0-1
- update to 9.23.0

* Wed Feb 28 2024 liupei <liupei@kylinos.cn> - 9.22.0-1
- update to 9.22.0

* Mon Nov 27 2023 liupei <liupei@kylinos.cn> - 9.21.4-1
- update to 9.21.4

* Fri Mar 11 2022 jiangxinyu <jiangxinyu@kylinos.cn> - 9.17.0-1
- update to 9.17.0

* Fri Aug 13 2021 yangzhao <yangzhao1@kylinos.cn> - 9.5.0-6
- Fix gcc 10 build multiple definition error

* Thu Nov 27 2020 jiangxinyu <jiangxinyu@kylinos.cn> - 9.5.0-5
- Resolve resource-agents conflict when installing drbd-rgmanager package

* Fri Oct 30 2020 jiangxinyu <jiangxinyu@kylinos.cn> - 9.5.0-4
- Rebuilt for openEuler20.03 LTS

* Thu Apr 16 2020 houjian<jian.hou@kylinos.cn> - 9.5.0-3
- Init drbd  project
